@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """Analyze a shell history."""
 
 # Third party modules
@@ -11,7 +9,7 @@ from shell_history_analysis.analyze import main
 
 @click.command()
 @click.argument("filename", type=click.Path(exists=True))
-@click.option("--shell", type=click.Choice({"zsh", "fish", "bash"}))
+@click.option("--shell", type=click.Choice(["zsh", "fish", "bash"]))
 @click.option(
     "--grouping",
     type=click.Path(exists=True),
